@@ -1,3 +1,4 @@
+from __future__ import print_function
 from fusil.project_agent import ProjectAgent
 from fusil.tools import minmax
 from datetime import datetime
@@ -53,17 +54,17 @@ class AggressivityAgent(ProjectAgent):
         if CREATE_GRAPH_DAT and not self.graph_data:
             filename = self.project().createFilename('aggressivity.dat')
             self.graph_data = open(filename, 'w')
-            print >>self.graph_data, "# Aggressivity data"
-            print >>self.graph_data, "# Started at %s" % datetime.now()
-            print >>self.graph_data, "#"
-            print >>self.graph_data, "# session_index score aggressivity"
+            print("# Aggressivity data", file=self.graph_data)
+            print("# Started at %s" % datetime.now(), file=self.graph_data)
+            print("#", file=self.graph_data)
+            print("# session_index score aggressivity", file=self.graph_data)
         if self.project().success_score <= score:
             score = 1.0
         else:
             score = minmax(-1.0, score, 1.0)
         if self.graph_data:
-            print >>self.graph_data, "%u\t%.3f\t%.3f" % (
-                self.last_session_index, score, self.aggressivity)
+            print("%u\t%.3f\t%.3f" % (
+                self.last_session_index, score, self.aggressivity), file=self.graph_data)
             self.graph_data.flush()
 
     def on_session_done(self, score):
