@@ -9,6 +9,7 @@ from fusil.mas.application_agent import ApplicationAgent
 from fusil.mas.mta import MTA
 from fusil.mas.univers import Univers
 from ptrace.error import PTRACE_ERRORS, writeError
+from ptrace.os_tools import RUNNING_PYTHON3
 from fusil.application_logger import ApplicationLogger
 from fusil.process.tools import limitMemory, beNice
 from fusil.file_tools import relativePath
@@ -139,10 +140,10 @@ class Application(ApplicationAgent):
 
         # Just want to know the version?
         if self.options.version:
-            print "Fusil version %s" % VERSION
-            print "License: %s" % LICENSE
-            print "Website: %s" % WEBSITE
-            print
+            print("Fusil version %s" % VERSION)
+            print("License: %s" % LICENSE)
+            print("Website: %s" % WEBSITE)
+            print("")
             exit(0)
 
         if self.options.quiet:
@@ -189,7 +190,7 @@ class Application(ApplicationAgent):
         # Read configuration
         try:
             self.config = FusilConfig()
-        except ConfigError, err:
+        except ConfigError as err:
             self.fatalError(u"Configuration error: %s" % err)
 
         # Read command line options
@@ -203,7 +204,7 @@ class Application(ApplicationAgent):
         # Check the configuration
         try:
             self.processConfig()
-        except ConfigError, err:
+        except ConfigError as err:
             self.fatalError(u"Configuration error: %s" % err)
 
         # Limit Fusil environment
@@ -311,9 +312,13 @@ class Application(ApplicationAgent):
             answer = None
             while answer not in (u"yes", u"no", u""):
                 if answer:
-                    answer = raw_input('Please answer "yes" or "no": ')
+                    prompt = 'Please answer "yes" or "no": '
                 else:
-                    answer = raw_input('Do you want to continue? (yes/NO) ')
+                    prompt = 'Do you want to continue? (yes/NO) '
+                if RUNNING_PYTHON3:
+                    answer = input(prompt)
+                else:
+                    answer = raw_input(prompt)
                 answer = answer.strip().lower()
             confirm = (answer == 'yes')
         except (KeyboardInterrupt, EOFError):
@@ -367,7 +372,7 @@ class Application(ApplicationAgent):
             self.agents.clear()
         except KeyboardInterrupt:
             self.interrupt("Application cleanup interrupted!")
-        except PTRACE_ERRORS, error:
+        except PTRACE_ERRORS as error:
             writeError(None, error, "AGENT DEINIT ERRORT")
             self.exitcode = 1
         self.deinitX11()
@@ -398,7 +403,7 @@ class Application(ApplicationAgent):
                 self.univers.execute(self.project)
         except KeyboardInterrupt:
             self.interrupt("Fuzzer execution interrupted!")
-        except PTRACE_ERRORS, error:
+        except PTRACE_ERRORS as error:
             writeError(self, error, "Fuzzer execution error")
             self.exitcode = 1
         self.project.deactivate()
@@ -447,7 +452,7 @@ class Application(ApplicationAgent):
             self.runProject()
         except KeyboardInterrupt:
             self.interrupt("Project interrupted!")
-        except PTRACE_ERRORS, error:
+        except PTRACE_ERRORS as error:
             writeError(self, error)
             self.exitcode = 1
         if exit_at_end:
