@@ -19,7 +19,7 @@ class Option:
 
     def __str__(self):
         text = self.format
-        arguments = tuple( ("ARG%s" % index) for index in xrange(1, self.nb_argument+1) )
+        arguments = tuple( ("ARG%s" % index) for index in range(1, self.nb_argument+1) )
         return text % arguments
 
 class CommandHelpParser:
