@@ -9,7 +9,7 @@ if RUNNING_LINUX:
 def safeMkdir(path):
     try:
         mkdir(path)
-    except OSError, err:
+    except OSError as err:
         if err.errno == EEXIST:
             return
         else:
