@@ -1,9 +1,10 @@
-from ptrace.six import b
-from fusil.project_agent import ProjectAgent
 from errno import EBADF
+from fusil.project_agent import ProjectAgent
 from fusil.score import scoreLogFunc
 from fusil.tools import makeFilename
 from os.path import basename
+from ptrace.six import b
+from ptrace.six import text_type, iteritems
 from time import time
 import re
 
@@ -78,13 +79,13 @@ class FileWatch(ProjectAgent):
         return FileWatch(project, input_file, basename(filename), start)
 
     def ignoreRegex(self, regex, flags=0):
-        if isinstance(regex, unicode):
+        if isinstance(regex, text_type):
             regex = regex.encode("ASCII")
         regex = re.compile(regex, flags)
         self.ignore.append(regex.search)
 
     def addRegex(self, regex, score, flags=0):
-        if isinstance(regex, unicode):
+        if isinstance(regex, text_type):
             regex = regex.encode("ASCII")
         match = re.compile(regex, flags).search
         self.regexs.append((regex, score, match))
@@ -94,9 +95,9 @@ class FileWatch(ProjectAgent):
         for text, score, match in self.regexs:
             yield (text, score, match)
 
-        for text, score in self.words.iteritems():
+        for text, score in iteritems(self.words):
             text = text.lower()
-            if isinstance(text, unicode):
+            if isinstance(text, text_type):
                 text = text.encode("ASCII")
             regex = re.escape(text)
             regex = b(r'(?:^|\W)') + regex + b(r'(?:$|\W)')
@@ -215,7 +216,7 @@ class FileWatch(ProjectAgent):
                     return
                 for line in self.splitlines(data):
                     yield line
-        except IOError, err:
+        except IOError as err:
             if err.errno == EBADF:
                 self.error("Unable to read data: closed file (Bad file descriptor error)")
                 self.file_obj = None
