@@ -3,7 +3,11 @@ Functions to recompute (fix) CRC32 checksums of an PNG picture.
 """
 
 from array import array
-from StringIO import StringIO
+try:
+    from io import StringIO
+except ImportError:
+    # Python 2
+    from StringIO import StringIO
 from fusil.bits import bytes2uint, BIG_ENDIAN, uint2bytes
 from zlib import crc32
 from logging import info
