@@ -223,8 +223,8 @@ class IncrMangle(MangleAgent):
             version = previous.createVersion(self, len(data))
             self.warning("New version %s based on %s" % (version, previous))
             self.versions.addVersion(version)
-        except IncrMangleError, err:
-            for index in xrange(10):
+        except IncrMangleError as err:
+            for index in range(10):
                 self.error(str(err))
             version = self.rollbackLast()
 
