@@ -1,3 +1,4 @@
+from __future__ import print_function
 from sys import stderr
 from fusil.mas.message import Message
 from fusil.mas.mailbox import Mailbox
@@ -45,7 +46,7 @@ class Agent(object):
         except KeyboardInterrupt:
             self.error("Agent destruction interrupted!")
             self.send('application_interrupt')
-        except PTRACE_ERRORS, error:
+        except PTRACE_ERRORS as error:
             writeError(self, error, "Agent destruction error")
 
     def destroy(self):
@@ -129,7 +130,7 @@ class Agent(object):
             func = getattr(self.logger, level)
         except AttributeError:
             if level == "error":
-                print >>stderr, "(no logger)", message
+                print("(no logger)", message, file=stderr)
             return
         func(message, sender=self)
 
