@@ -12,7 +12,7 @@ class AgentList:
     def _destroy(self, agent):
         try:
             agent.deactivate()
-        except PTRACE_ERRORS, error:
+        except PTRACE_ERRORS as error:
             writeError(None, error, "Agent deinit error")
         agent.unregister(False)
 
