@@ -12,8 +12,6 @@ class Message:
             function = "on_%s" % self.event
             function = getattr(agent, function)
         except AttributeError:
-            agent.debug("%r skipped" % self)
             return
-        agent.debug("Process %r" % self)
         function(*self.arguments)
 
