@@ -23,7 +23,7 @@ class Logger:
     def display(self, message):
         if not self.show:
             return
-        print message
+        print(message)
 
 class MTA:
     def __init__(self, logger=None):
