@@ -25,7 +25,7 @@ class NetworkClient(ProjectAgent):
             self.socket.settimeout(timeout)
             self.info("Connect to %s" % formatAddress(family, address))
             self.socket.connect(address)
-        except socket_error, err:
+        except socket_error as err:
             writeError(self, err, "Unable to connect to %s" %
                 formatAddress(family, address))
             self.socket = None
@@ -65,7 +65,7 @@ class NetworkClient(ProjectAgent):
         try:
             self.socket.settimeout(timeout)
             self.socket.send(data)
-        except socket_error, err:
+        except socket_error as err:
             self.warning("Send error: %s" % formatError(err))
             self.closeSocket()
             self.send('session_stop')
@@ -95,7 +95,7 @@ class NetworkClient(ProjectAgent):
                 data = self.socket.recv(buffer_size)
             except socket_timeout:
                 break
-            except socket_error, err:
+            except socket_error as err:
                 code = err.args[0]
                 if not time_diff and code == EAGAIN:
                     break
