@@ -11,7 +11,7 @@ class HttpServer(TcpServer):
         # Read data
         try:
             data = client.recvBytes()
-        except ServerClientDisconnect, error:
+        except ServerClientDisconnect:
             self.clientDisconnection(client)
             return
         if not data:
@@ -56,6 +56,6 @@ class HttpServer(TcpServer):
                 data = header
             client.sendBytes(data)
             client.close()
-        except ServerClientDisconnect, error:
+        except ServerClientDisconnect:
             self.clientDisconnection(client)
 
