@@ -72,14 +72,14 @@ class AttachProcessPID(ProjectAgent):
             try:
                 stat('/proc/%s' % self.pid)
                 return True
-            except OSError, err:
+            except OSError as err:
                 if err.errno != ENOENT:
                     raise
         else:
             try:
                 kill(self.pid, 0)
                 return True
-            except OSError, err:
+            except OSError as err:
                 if err.errno != ESRCH:
                     raise
         self.error("Process %s disappeared" % self.pid)
@@ -91,7 +91,7 @@ class AttachProcessPID(ProjectAgent):
             return True
         try:
             memory = readProcessStatm(self.pid)[0]
-        except ProcError, error:
+        except ProcError as error:
             self.error(error)
             self.stop()
             return False
