@@ -43,7 +43,7 @@ class EnvironmentVariable:
         if self.max_count:
             max_count = min(max_count, self.max_count)
         count = randint(self.min_count, max_count)
-        for index in xrange(count):
+        for index in range(count):
             name = self.createName()
             value = self.createValue()
             yield (name, value)
@@ -93,11 +93,14 @@ class EnvVarRandom(BytesGenerator, EnvironmentVariable):
 class Environment(ProjectAgent):
     def __init__(self, process):
         ProjectAgent.__init__(self, process.project(), "%s:env" % process.name)
-        self.copies = []
-        self.variables = []
+        self.clear()
         if RUNNING_WINDOWS:
             self.copies.append('SYSTEMROOT')
 
+    def clear(self):
+        self.copies = []
+        self.variables = []
+
     def set(self, name, value, max_count=1):
         """
         Set a fixed environment variable value: create an EnvVarValue.
