@@ -1,10 +1,10 @@
-from ptrace.six import binary_type
-from fusil.xhost import xhostCommand
-from fusil.write_code import WriteCode
-from sys import executable, getfilesystemencoding, path as sys_path
-from os.path import normpath
-import itertools
 from fusil.python_tools import RUNNING_PYTHON3
+from fusil.write_code import WriteCode
+from fusil.xhost import xhostCommand
+from os.path import normpath
+from ptrace.six import itervalues, iteritems, binary_type, text_type
+from sys import executable, getfilesystemencoding, path as sys_path
+import itertools
 
 def formatValue(value):
     r"""
@@ -28,7 +28,7 @@ def formatValue(value):
     else:
         repeat = False
     if repeat:
-        return repr(value[0]) + ' * %s' % len(value)
+        return repr(value[:1]) + ' * %s' % len(value)
     else:
         return repr(value)
 
@@ -77,7 +77,7 @@ class WriteReplayScript(WriteCode):
         if args:
             line += u' % '
             if len(args) == 1:
-                line += unicode(args[0])
+                line += text_type(args[0])
             else:
                 line += u'(%s)' % ', '.join(args)
         line += ')'
@@ -259,9 +259,9 @@ class WriteReplayScript(WriteCode):
 
         self.write(0, u'gdb_arguments = []')
         self.write(0, u'for arg in arguments[1:]:')
-        self.write(1, ur'''arg = arg.replace('\\', r'\\')''')
-        self.write(1, ur'''arg = arg.replace('"', r'\\"')''')
-        self.write(1, ur'''arg = '"%s"' % arg''')
+        self.write(1, r'''arg = arg.replace('\\', r'\\')''')
+        self.write(1, r'''arg = arg.replace('"', r'\\"')''')
+        self.write(1, r'''arg = '"%s"' % arg''')
         self.write(1, u'gdb_arguments.append(arg)')
 
         self.writePrint(0, u'run %s', u'" ".join(gdb_arguments)', file=u'cmd')
@@ -354,7 +354,7 @@ class WriteReplayScript(WriteCode):
         cwd_bytes = cwd.encode(fs_charset)
 
         need_cwd_bytes = False
-        for value in itertools.chain(arguments, env.itervalues()):
+        for value in itertools.chain(arguments, itervalues(env)):
             if not isinstance(value, binary_type):
                 continue
             if cwd_bytes not in value:
@@ -377,7 +377,7 @@ class WriteReplayScript(WriteCode):
 
         if env:
             self.write(0, u'env = {')
-            for name, value in env.iteritems():
+            for name, value in iteritems(env):
                 value = formatPath(value, cwd, cwd_bytes)
                 self.write(1, u'"%s": %s,' % (name, value))
             self.write(0, u'}')
@@ -422,7 +422,7 @@ class WriteReplayScript(WriteCode):
 
         # Create the script file
         filename = session.createFilename("replay.py")
-        self.createFile(filename, 0755)
+        self.createFile(filename, 0o755)
         self.pythonImports()
         self.globalVariables(process, config, cwd, arguments, env)
         self.setSysPath()
