@@ -1,9 +1,9 @@
 from os import getenv, access, X_OK, pathsep, devnull, getcwd
-from os.path import dirname, normpath
-from subprocess import Popen, STDOUT
+from os.path import dirname, normpath, join as path_join, isabs
 from ptrace.os_tools import RUNNING_WINDOWS
-from os.path import join as path_join, isabs
 from ptrace.signames import signalName
+from ptrace.six import string_types
+from subprocess import Popen, STDOUT
 import re
 
 if RUNNING_WINDOWS:
@@ -100,7 +100,7 @@ def runCommand(logger, command, stdin=False, stdout=True, options=None, raise_er
     process is killed by a signal. If raise_error=False, return the status and
     don't raise RuntimeError if status is not nul.
     """
-    if isinstance(command, (str, unicode)):
+    if isinstance(command, string_types):
         command_str = repr(command)
     else:
         command_str = ' '.join(command)
