@@ -1,21 +1,25 @@
 from fusil.project_agent import ProjectAgent
-from fusil.process.tools import dumpProcessInfo, displayProcessStatus
 from weakref import ref as weakref_ref
 from ptrace.os_tools import RUNNING_LINUX
 if RUNNING_LINUX:
     from fusil.process.cpu_probe import CpuProbe
 
+DEFAULT_EXITCODE_SCORE = 0.50
+DEFAULT_TIMEOUT_SCORE = 1.0
+DEFAULT_SIGNAL_SCORE = 1.0
+
 class WatchProcess(ProjectAgent):
     def __init__(self, process,
-    exitcode_score=0.50, signal_score=1.0, default_score=0.0,
-    timeout_score=1.0):
+    exitcode_score=DEFAULT_EXITCODE_SCORE,
+    signal_score=DEFAULT_SIGNAL_SCORE,
+    default_score=0.0,
+    timeout_score=DEFAULT_TIMEOUT_SCORE):
         self.process = weakref_ref(process)
         project = process.project()
         ProjectAgent.__init__(self, project, "watch:%s" % process.name)
-        if RUNNING_LINUX:
+        if RUNNING_LINUX and project.config.use_cpu_probe:
             self.cpu = CpuProbe(project, "%s:cpu" % self.name)
         else:
-            self.warning("CpuProbe is not available")
             self.cpu = None
 
         # Score if process exited normally
@@ -45,7 +49,6 @@ class WatchProcess(ProjectAgent):
             self.prepareProcess()
 
     def prepareProcess(self):
-        dumpProcessInfo(self.info, self.pid)
         if self.cpu:
             self.cpu.setPid(self.pid)
 
@@ -61,10 +64,6 @@ class WatchProcess(ProjectAgent):
 
     def processDone(self, status):
         self.score = self.computeScore(status)
-        if not self.process().timeout_reached:
-            log = self.scoreLogFunc()
-            displayProcessStatus(log, status)
-        self.send("process_done", self.process(), status)
         self.send('session_stop')
         self.pid = None
 
