@@ -8,15 +8,20 @@ class SessionAgent(ProjectAgent):
         else:
             mta = session.mta()
             project = session.project()
-        self.session = weakref_ref(session)
+        self._session = weakref_ref(session)
         ProjectAgent.__init__(self, project, name, mta=mta)
         self.activate()
 
+    def session(self):
+        return self._session()
+
     def register(self):
         ProjectAgent.register(self)
         self.session().registerAgent(self)
 
     def unregister(self, destroy=True):
         ProjectAgent.unregister(self, destroy)
-        self.session().unregisterAgent(self, destroy)
+        session = self.session()
+        if session:
+            session.unregisterAgent(self, destroy)
 
