@@ -7,5 +7,5 @@ class TerminalEcho(ProjectAgent):
 
     def deinit(self):
         if enableEchoMode():
-            self.error("Terminal: restore echo mode to stdin")
+            self.info("Terminal: restore echo mode to stdin")
 
