@@ -1,4 +1,6 @@
-from itertools import izip
+from ptrace.six import text_type
+from ptrace.six.moves import zip as izip
+
 import re
 
 def minmax(min_value, value, max_value):
@@ -38,20 +40,20 @@ def timedeltaSeconds(delta):
         + delta.days * 3600 * 24
 
 def makeUnicode(text):
-    if isinstance(text, unicode):
+    if isinstance(text, text_type):
         return text
     try:
-        return unicode(text, "utf8")
+        return text_type(text, "utf8")
     except UnicodeError:
         pass
-    return unicode(text, "ISO-8859-1")
+    return text_type(text, "ISO-8859-1")
 
 def makeFilename(text):
     """
     >>> makeFilename('Fatal error!')
     'fatal_error'
     """
-    if isinstance(text, unicode):
+    if isinstance(text, text_type):
         text = text.lower()
         text = re.sub(u'[^a-z_-]', '_', text)
         text = re.sub(u'_{2,}', '_', text)
@@ -59,8 +61,8 @@ def makeFilename(text):
     else:
         # byte string
         text = text.lower()
-        text = re.sub('[^a-z_-]', '_', text)
-        text = re.sub('_{2,}', '_', text)
-        text = re.sub('_$', '', text)
+        text = re.sub(b'[^a-z_-]', '_', text)
+        text = re.sub(b'_{2,}', '_', text)
+        text = re.sub(b'_$', '', text)
     return text
 
