@@ -1,4 +1,5 @@
 from os import chmod
+from ptrace.six import text_type
 
 class WriteCode:
     def __init__(self):
@@ -31,7 +32,7 @@ class WriteCode:
         self.base_level = level
 
     def indentLine(self, level, text):
-        if not isinstance(text, unicode):
+        if not isinstance(text, text_type):
             text = unicode(text, 'ASCII')
         return self.indent * (self.base_level + level) + text
 
