@@ -57,12 +57,12 @@ def displayWindows(root, level=0):
     if not children:
         return
     indent = ("   "*level)
-    print indent + "|== %s ===" % formatWindow(root)
+    print(indent + "|== %s ===" % formatWindow(root))
     parent = tree.parent
     if parent:
-        print indent + "|-- parent: %s" % formatWindow(parent)
+        print(indent + "|-- parent: %s" % formatWindow(parent))
     for window in children:
-        print indent + "|-> %s" % formatWindow(window)
+        print(indent + "|-> %s" % formatWindow(window))
         displayWindows(window, level+1)
 
 def sendKey(window, keycode, modifiers=0, released=True):
