@@ -1,9 +1,9 @@
 #!/bin/sh
 DATA=$1
-OUTPUT=graph.png
+OUTPUT=/tmp/graph.png
 
 if [ "x$DATA" = "x" ]; then
-    echo "usage: $0 graph.dat"
+    echo "usage: $0 aggressivity.dat"
     exit 1
 fi
 
@@ -12,6 +12,9 @@ if [ ! -f "$DATA" ]; then
     exit 1
 fi
 
+# Exit on error
+set -e
+
 cat <<EOF | gnuplot
 # Output: 800x600 PNG file
 set terminal png size 800, 600
