@@ -4,12 +4,12 @@ from sys import exit, path as sys_path
 from os.path import dirname
 
 def testDoc(filename, name=None):
-    print "--- %s: Run tests" % filename
+    print("--- %s: Run tests" % filename)
     failure, nb_test = testfile(
         filename, optionflags=ELLIPSIS, name=name)
     if failure:
         exit(1)
-    print "--- %s: End of tests" % filename
+    print("--- %s: End of tests" % filename)
 
 def importModule(name):
     mod = __import__(name)
@@ -19,12 +19,12 @@ def importModule(name):
     return mod
 
 def testModule(name):
-    print "--- Test module %s" % name
+    print("--- Test module %s" % name)
     module = importModule(name)
     failure, nb_test = testmod(module)
     if failure:
         exit(1)
-    print "--- End of test"
+    print("--- End of test")
 
 def main():
     fusil_dir = dirname(__file__)
